==> ae_paths-0.0.2.tar.gz: ae_paths-0.0.2/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# paths portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_paths/master?logo=python)](
    https://gitlab.com/ae-group/ae_paths)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_paths)](
    https://pypi.org/project/ae-paths/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes for to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_paths/coverage.svg)](
    https://ae-group.gitlab.io/ae_paths/coverage/ae_paths_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_paths/mypy.svg)](
    https://ae-group.gitlab.io/ae_paths/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_paths/pylint.svg)](
    https://ae-group.gitlab.io/ae_paths/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_paths)](
    https://pypi.org/project/ae-paths/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_paths)](
    https://pypi.org/project/ae-paths/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_paths)](
    https://pypi.org/project/ae-paths/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_paths)](
    https://pypi.org/project/ae-paths/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_paths)](
    https://libraries.io/pypi/ae-paths)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_paths)](
    https://pypi.org/project/ae-paths/#files)


## installation


Execute the following command for to use the ae.paths module in your
application. It will install ae.paths into your python (virtual) environment:
 
```shell script
pip install ae-paths
```

If you instead want to contribute to this portion then first fork
[the ae_paths repository at GitLab](https://gitlab.com/ae-group/ae_paths "ae.paths code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_paths):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or for to extend the portion documentation.
For to contribute only to the unit tests or the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.paths.html#module-ae.paths
"ae_paths documentation").

<!-- Common files version 0.0.55 deployed  version 0.0.1 (with 0.0.55)
     to https://gitlab.com/ae-group as ae_paths module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project as ae-paths package.
-->

==> ae_paths-0.1.18.tar.gz: ae_paths-0.1.18/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# paths portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_paths/master?logo=python)](
    https://gitlab.com/ae-group/ae_paths)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_paths)](
    https://pypi.org/project/ae-paths/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes for to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_paths/coverage.svg)](
    https://ae-group.gitlab.io/ae_paths/coverage/ae_paths_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_paths/mypy.svg)](
    https://ae-group.gitlab.io/ae_paths/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_paths/pylint.svg)](
    https://ae-group.gitlab.io/ae_paths/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_paths)](
    https://pypi.org/project/ae-paths/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_paths)](
    https://pypi.org/project/ae-paths/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_paths)](
    https://pypi.org/project/ae-paths/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_paths)](
    https://pypi.org/project/ae-paths/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_paths)](
    https://libraries.io/pypi/ae-paths)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_paths)](
    https://pypi.org/project/ae-paths/#files)


## installation


Execute the following command for to use the ae.paths module in your
application. It will install ae.paths into your python (virtual) environment:
 
```shell script
pip install ae-paths
```

If you instead want to contribute to this portion then first fork
[the ae_paths repository at GitLab](https://gitlab.com/ae-group/ae_paths "ae.paths code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_paths):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or for to extend the portion documentation.
For to contribute only to the unit tests or the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.paths.html#module-ae.paths
"ae_paths documentation").

<!-- Common files version 0.0.60 deployed version 0.1.2 (with 0.0.60)
     to https://gitlab.com/ae-group as ae_paths module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-paths as namespace portion ae-paths.
-->
